dberror

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Classifier

type Classifier interface {
	IsNoRowsError(err error) bool
	IsForeignKeyViolationError(err error) bool
	IsUniqueViolationError(err error) bool
}

Classifier classifies storage-layer errors into common categories that repositories and service adapters can map into domain or application errors.

Directories

Path Synopsis

Jump to